# Worker Status manager

Worker status management.

- add “irregular penalty” config in shift settings
- compute next countdown date and future alert date for irregular workers, taking into account holidays and exemption status
- compute the future alert date for irregular workers, taking into account holidays and exemption status
- compute regular and irregular statuses according to alert start day, alert delay, grace delay and time extensions, taking into account holidays and exemption status
- recompute status and counters when a shift undergoes a state change
- postpone alert start time based on holidays and extension status
- handle is_regular and is_compensation consistency on shifts, on worker change and by raising a validation error if the fields are not properly set

Table of contents

- Changelog
- Bug Tracker
- Credits
  - Authors
  - Contributors
  - Maintainers

# Changelog

12.0.1.1.0 (2022-06-23) Features

- Do not apply a penalty to irregular customers twice in a row. Best explained through an example.

  Imagine the following ‘sr’ of an irregular worker:

  0 -> -2 (cron, penalty) -> -1 (work a shift) -> 0 (work another shift) -> ??? (cron)

  The last step should go to -1 instead of -2. The penalty should not be given again until sr has reached 1. (#388)

# Bug Tracker

Bugs are tracked on GitHub Issues. In case of trouble, please check there if your issue has already been reported. If you spotted it first, help us to smash it by providing a detailed and welcomed feedback.

Do not contact contributors directly about support or help with technical issues.

# Credits

## Authors

- Thibault Francois
- Elouan Le Bars
- Coop IT Easy SC

## Contributors

- BEES coop - Cellule IT
- Coop IT Easy SC

## Maintainers

This module is part of the beescoop/Obeesdoo project on GitHub.

You are welcome to contribute.